;************************ Program Variables *****************************
;
; Port assignment: Bit variables
;
rx_pin          EQU     ra.2            ;UART receive input (Connect to RS232's TXD)
tx_pin          EQU     ra.3            ;UART transmit output (Connect to RS232's RXD)

;****** Register definitions (bank 0)

                org     8               ;First register address in main memory
                                        ;bank
temp            ds      1               ;Temporary storage
byte            ds      1               ;Temporary UART shift register
flags           DS      1               ;Program flags register
number_low      ds      1               ;Low receive byte
number_high     ds      1               ;High receive byte
hex             ds      1               ;Value of received hex number
string          ds      1               ;Indirect pointer for text output

rx_flag         EQU     flags.5         ;Signals reception of one byte

                org     10h             ;Variables in bank 3
serial          =       $               ;UART bank

tx_high         ds      1               ;Low transmit byte
tx_low          ds      1               ;High transmit byte
tx_count        ds      1               ;Number of remaining bits to be sent
tx_divide       ds      1               ;Counter for transmit timer (/16)
rx_count        ds      1               ;Number of bits received
rx_divide       ds      1               ;Counter for receive timer
rx_byte         ds      1               ;Buffer for received bytes

; The next three parameters determine the baud rate of the UART.
; The values of baud_bit, and int_period control the baud rate as follows:
; 
; Baud rate = 50 MHz/(2 ^ baud_bit * int_period * RTCC_prescaler)
;     Important: - 1 <= baud_bit <= 7
;                - int_period must be less than 256 and longer than
;                  the total time required by the ISR instructions. Changing
;                  int_period will also influence the timing of other VPs
;                  that are possibly executed within the ISR.
;                - start_delay must be set to (2 ^ baud_bit) * 1,5 + 1.
;
; Values for various baud rates:
;
; *** 2400 Baud (For baud rates below 2,400, the RTCC prescaler must be
;                activated.)
;baud_bit       =       7
;start_delay    =       128+64+1
;int_period     =       163
;
; *** 9600 baud
;baud_bit        =      5
;start_delay     =      32+16+1 ;16+8+1
;int_period      =      163
;
; *** 19,200 Baud
;baud_bit        =      4
;start_delay     =      16+8+1
;int_period      =      163
;
; *** 38,400 baud
;baud_bit       =       3
;start_delay    =       8+4+1
;int_period     =       163
;
; *** 57,600 baud
;baud_bit       =       2
;start_delay    =       4+2+1
;int_period     =       217
;
; *** 115.2k baud
baud_bit       =       1
start_delay    =       2+1+1
int_period     =       217
;
; *** 230.4k baud (for higher baud rates, int_period must be reduced - see
;                  above!)
;baud_bit       =       0
;start_delay    =       1+1+0 ;1+0+0
;int_period     =       217

